Chat.added_to_experiment() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Chat.added_to_experiment()

Chat.added_to_experiment(exp)

  Tells the element that it was added to an experiment.

  The experiment is made available to the element, and the element’s logging interface initializes its experiment-specific logging.

  This is also the place where the element’s name is checked for experiment-wide uniqueness.

  Parameters

    experiment – The alfred experiment to which the element was added.